cheesecake.model.Class

Package cheesecake :: Module model :: Class Class |
[hide private]
[frames] | no frames]

## Class Class
source code

      object --+
               |
    Documentable --+
                   |
                  Class

Instance Methods | [hide private]
| setup(self)
Inherited from `Documentable`: `__getstate__`, `__init__`, `__repr__`, `dottedNameToFullName`, `fullName`, `name2fullname`, `resolveDottedName`, `shortdocstring` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Variables | [hide private]
kind |
Inherited from `object`: `__class__`

Method Details | [hide private]

### setup(self) | source code
Overrides: Documentable.setup

Class Variable Details | [hide private]

    ### kind Value:
        'Class'